pub struct PullConflict {
pub key: RecordKey,
pub local: Box<Record>,
pub remote: Box<Record>,
}Expand description
A record that diverged on both sides of a pull and could not be auto-merged; the local version is kept and both sides are surfaced for resolution.
Fields
key: RecordKeylocal: Box<Record>remote: Box<Record>Trait Implementations
Sourceimpl Clone for PullConflict
impl Clone for PullConflict
Sourcefn clone(&self) -> PullConflict
fn clone(&self) -> PullConflict
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for PullConflict
impl RefUnwindSafe for PullConflict
impl Send for PullConflict
impl Sync for PullConflict
impl Unpin for PullConflict
impl UnsafeUnpin for PullConflict
impl UnwindSafe for PullConflict